**Example 1: 停用任务**



Input: 

```
tccli tsf DisableTask --cli-unfold-argument  \
    --TaskId task-klwqrnlw
```

Output: 
```
{
    "RequestId": "3c140219-cfe9-470e-b241-907877d6fb03",
    "Response": true
}
```

